# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['jedi_language_server']

package_data = \
{'': ['*']}

install_requires = \
['click>=7.0', 'jedi>=0.17.0', 'pygls>=0.8.1']

entry_points = \
{'console_scripts': ['jedi-language-server = jedi_language_server.cli:cli']}

setup_kwargs = {
    'name': 'jedi-language-server',
    'version': '0.10.2',
    'description': 'A language server for Jedi!',
    'long_description': '# jedi-language-server\n\n[![image-version](https://img.shields.io/pypi/v/jedi-language-server.svg)](https://python.org/pypi/jedi-language-server)\n[![image-license](https://img.shields.io/pypi/l/jedi-language-server.svg)](https://python.org/pypi/jedi-language-server)\n[![image-python-versions](https://img.shields.io/pypi/pyversions/jedi-language-server.svg)](https://python.org/pypi/jedi-language-server)\n\nA [Language Server](https://microsoft.github.io/language-server-protocol/) for the latest version(s) of [Jedi](https://jedi.readthedocs.io/en/latest/).\n\n**Note:** this tool is actively used by its primary author. He\'s happy to review pull requests / respond to issues you may discover.\n\n## Installation\n\nFrom your command line (bash / zsh), run:\n\n```bash\npip install -U jedi-language-server\n```\n\n`-U` ensures that you\'re pulling the latest version from pypi.\n\nAlternatively, consider using [pipx](https://github.com/pipxproject/pipx) to keep jedi-language-server isolated from your other Python dependencies.\n\n## Overview\n\njedi-language-server aims to support all of Jedi\'s capabilities and expose them through the Language Server Protocol. It currently supports the following Language Server requests:\n\n- [textDocument/completion](https://microsoft.github.io/language-server-protocol/specifications/specification-current/#textDocument_completion)\n- [textDocument/definition](https://microsoft.github.io/language-server-protocol/specifications/specification-current/#textDocument_definition)\n- [textDocument/documentHighlight](https://microsoft.github.io/language-server-protocol/specification#textDocument_documentHighlight)\n- [textDocument/documentSymbol](https://microsoft.github.io/language-server-protocol/specifications/specification-current/#textDocument_documentSymbol)\n- [textDocument/hover](https://microsoft.github.io/language-server-protocol/specifications/specification-current/#textDocument_hover)\n- [textDocument/publishDiagnostics](https://microsoft.github.io/language-server-protocol/specification#textDocument_publishDiagnostics)\n- [textDocument/references](https://microsoft.github.io/language-server-protocol/specifications/specification-current/#textDocument_references)\n- [textDocument/rename](https://microsoft.github.io/language-server-protocol/specifications/specification-current/#textDocument_rename)\n- [textDocument/signatureHelp](https://microsoft.github.io/language-server-protocol/specification#textDocument_signatureHelp)\n- [workspace/symbol](https://microsoft.github.io/language-server-protocol/specifications/specification-current/#workspace_symbol)\n\n## Editor Setup\n\nThe following instructions show how to use jedi-language-server with your development tooling. The instructions assume you have already installed jedi-language-server.\n\n### Neovim\n\nUse [coc.nvim](https://github.com/neoclide/coc.nvim/wiki/Language-servers#register-custom-language-servers) with [coc-jedi](https://github.com/pappasam/coc-jedi).\n\n### Command line (bash / zsh)\n\nAt your terminal prompt:\n\n```bash\njedi-language-server\n```\n\njedi-language-server currently works only over IO. This may change in the future.\n\n## Configuration\n\njedi-language-server supports top-level configuration items in `coc-settings.json` (or your editor-equivalent configuration file). The following is a snippet of `coc-settings.json` with defaults:\n\n```json\n{\n  "jedi.enabled": true,\n  "jedi.completion.triggerCharacters": [".", "\'", "\\""],\n  "jedi.signatureHelp.triggerCharacters": ["(", ",", ")"],\n  "jedi.diagnostics.enabled": true,\n  "jedi.diagnostics.didOpen": true,\n  "jedi.diagnostics.didChange": true,\n  "jedi.diagnostics.didSave": true\n}\n```\n\n### jedi.enabled\n\nEnables (or disables) all jedi-language-server features (other than initialization)\n\n- type: `boolean`\n- default: `true`\n\n### jedi.completion.triggerCharacters\n\nDefines characters that trigger completion automatically when typed\n\n- type: `array<string>`\n- default: `[".", "\'", "\\""]`\n\n### jedi.signatureHelp.triggerCharacters\n\nDefines characters that trigger signature help automatically when typed\n\n- type: `array<string>`\n- default: `["(", ",", ")"]`\n\n### jedi.diagnostics.enabled\n\nEnables (or disables) diagnostics provided by Jedi\n\n- type: `boolean`\n- default: `true`\n\n### jedi.diagnostics.didOpen\n\nWhen diagnostics are enabled, run on document open\n\n- type: `boolean`\n- default: `true`\n\n### jedi.diagnostics.didChange\n\nWhen diagnostics are enabled, run on in-memory document change (eg, while you\'re editing, without needing to save to disk)\n\n- type: `boolean`\n- default: `true`\n\n### jedi.diagnostics.didSave\n\nWhen diagnostics are enabled, run on document save (to disk)\n\n- type: `boolean`\n- default: `true`\n\n## Additional Diagnostics\n\njedi-langugage-server provides diagnostics about syntax errors, powered by Jedi. If you would like additional diagnostics, we suggest using the powerful [diagnostic-language-server](https://github.com/iamcco/diagnostic-languageserver).\n\nIf using Neovim/coc, this can easily be done with [coc-diagnostic](https://github.com/iamcco/coc-diagnostic). Configure with [pylint](https://github.com/PyCQA/pylint) in your `coc-settings.json`:\n\n```json\n"diagnostic-languageserver.filetypes": {\n  "python": "pylint"\n},\n"diagnostic-languageserver.linters": {\n  "pylint": {\n    "sourceName": "pylint",\n    "command": "pylint",\n    "args": [\n      "--output-format",\n      "text",\n      "--score",\n      "no",\n      "--msg-template",\n      "\'{line}:{column}:{category}:{msg} ({msg_id}:{symbol})\'",\n      "%file"\n    ],\n    "formatPattern": [\n      "^(\\\\d+?):(\\\\d+?):([a-z]+?):(.*)$",\n      {\n        "line": 1,\n        "column": 2,\n        "security": 3,\n        "message": 4\n      }\n    ],\n    "securities": {\n      "informational": "hint",\n      "refactor": "info",\n      "convention": "info",\n      "warning": "warning",\n      "error": "error",\n      "fatal": "error"\n    },\n    "offsetColumn": 1,\n    "formatLines": 1\n  }\n}\n```\n\n## Local Development\n\nTo build and run this project from source:\n\n### Dependencies\n\nInstall the following tools manually:\n\n- [Poetry](https://github.com/sdispater/poetry#installation)\n- [GNU Make](https://www.gnu.org/software/make/)\n\n#### Recommended\n\n- [asdf](https://github.com/asdf-vm/asdf)\n\n### Get source code\n\n[Fork](https://help.github.com/en/github/getting-started-with-github/fork-a-repo) this repository and clone the fork to your development machine:\n\n```bash\ngit clone https://github.com/<YOUR-USERNAME>/jedi-language-server\ncd jedi-language-server\n```\n\n### Set up development environment\n\n```bash\nmake setup\n```\n\n### Run tests\n\n```bash\nmake test\n```\n\n## Inspiration\n\nPalantir\'s [python-language-server](https://github.com/palantir/python-language-server) inspired this project. Unlike python-language-server, jedi-language-server:\n\n- Uses `pygls` instead of creating its own low-level Language Server Protocol bindings\n- Supports one powerful 3rd party library: Jedi. By only supporting Jedi, we can focus on supporting all Jedi features without exposing ourselves to too many broken 3rd party dependencies (I\'m looking at you, [rope](https://github.com/python-rope/rope)).\n- Is supremely simple because of its scope constraints. Leave complexity to the Jedi [master](https://github.com/davidhalter). If the force is strong with you, please submit a PR!\n\n## Written by\n\nSamuel Roeca _samuel.roeca@gmail.com_\n',
    'author': 'Sam Roeca',
    'author_email': 'samuel.roeca@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/pappasam/jedi-language-server',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
